"""UI components for LazyLabel."""

from .main_window import MainWindow
from .control_panel import ControlPanel
from .right_panel import RightPanel
from .hotkey_dialog import HotkeyDialog

__all__ = ['MainWindow', 'ControlPanel', 'RightPanel', 'HotkeyDialog']